==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/fr-ca.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'fr-ca', {
	button: {
		title: 'Propriétés du bouton',
		text: 'Texte (Valeur)',
		type: 'Type',
		typeBtn: 'Bouton',
		typeSbm: 'Soumettre',
		typeRst: 'Réinitialiser'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Propriétés de la case à cocher',
		radioTitle: 'Propriétés du bouton radio',
		value: 'Valeur',
		selected: 'Sélectionné'
	},
	form: {
		title: 'Propriétés du formulaire',
		menu: 'Propriétés du formulaire',
		action: 'Action',
		method: 'Méthode',
		encoding: 'Encodage'
	},
	hidden: {
		title: 'Propriétés du champ caché',
		name: 'Nom',
		value: 'Valeur'
	},
	select: {
		title: 'Propriétés du champ de sélection',
		selectInfo: 'Info',
		opAvail: 'Options disponibles',
		value: 'Valeur',
		size: 'Taille',
		lines: 'lignes',
		chkMulti: 'Permettre les sélections multiples',
		opText: 'Texte',
		opValue: 'Valeur',
		btnAdd: 'Ajouter',
		btnModify: 'Modifier',
		btnUp: 'Monter',
		btnDown: 'Descendre',
		btnSetValue: 'Valeur sélectionnée',
		btnDelete: 'Supprimer'
	},
	textarea: {
		title: 'Propriétés de la zone de texte',
		cols: 'Colonnes',
		rows: 'Lignes'
	},
	textfield: {
		title: 'Propriétés du champ texte',
		name: 'Nom',
		value: 'Valeur',
		charWidth: 'Largeur de caractères',
		maxChars: 'Nombre maximum de caractères',
		type: 'Type',
		typeText: 'Texte',
		typePass: 'Mot de passe',
		typeEmail: 'Courriel',
		typeSearch: 'Recherche',
		typeTel: 'Numéro de téléphone',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/fr-ca.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'fr-ca', {
	button: {
		title: 'Propriétés du bouton',
		text: 'Texte (Valeur)',
		type: 'Type',
		typeBtn: 'Bouton',
		typeSbm: 'Soumettre',
		typeRst: 'Réinitialiser'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Propriétés de la case à cocher',
		radioTitle: 'Propriétés du bouton radio',
		value: 'Valeur',
		selected: 'Sélectionné',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Propriétés du formulaire',
		menu: 'Propriétés du formulaire',
		action: 'Action',
		method: 'Méthode',
		encoding: 'Encodage'
	},
	hidden: {
		title: 'Propriétés du champ caché',
		name: 'Nom',
		value: 'Valeur'
	},
	select: {
		title: 'Propriétés du champ de sélection',
		selectInfo: 'Info',
		opAvail: 'Options disponibles',
		value: 'Valeur',
		size: 'Taille',
		lines: 'lignes',
		chkMulti: 'Permettre les sélections multiples',
		required: 'Required', // MISSING
		opText: 'Texte',
		opValue: 'Valeur',
		btnAdd: 'Ajouter',
		btnModify: 'Modifier',
		btnUp: 'Monter',
		btnDown: 'Descendre',
		btnSetValue: 'Valeur sélectionnée',
		btnDelete: 'Supprimer'
	},
	textarea: {
		title: 'Propriétés de la zone de texte',
		cols: 'Colonnes',
		rows: 'Lignes'
	},
	textfield: {
		title: 'Propriétés du champ texte',
		name: 'Nom',
		value: 'Valeur',
		charWidth: 'Largeur de caractères',
		maxChars: 'Nombre maximum de caractères',
		required: 'Required', // MISSING
		type: 'Type',
		typeText: 'Texte',
		typePass: 'Mot de passe',
		typeEmail: 'Courriel',
		typeSearch: 'Recherche',
		typeTel: 'Numéro de téléphone',
		typeUrl: 'URL'
	}
} );
